==> factorio-draftsman-1.0.0.tar.gz: factorio-draftsman-1.0.0/draftsman/prototypes/accumulator.py <==
# accumulator.py
# -*- encoding: utf-8 -*-

from __future__ import unicode_literals

from draftsman import signatures
from draftsman.classes.entity import Entity
from draftsman.classes.mixins import ControlBehaviorMixin, CircuitConnectableMixin
from draftsman.error import DataFormatError
from draftsman.warning import DraftsmanWarning

from draftsman.data.entities import accumulators
from draftsman.data.signals import signal_dict

from schema import SchemaError
import six
import warnings


class Accumulator(ControlBehaviorMixin, CircuitConnectableMixin, Entity):
    """
    An entity that stores electricity for periods of high demand.
    """

    def __init__(self, name=accumulators[0], **kwargs):
        # type: (str, **dict) -> None
        """
        TODO
        """

        super(Accumulator, self).__init__(name, accumulators, **kwargs)

        for unused_arg in self.unused_args:
            warnings.warn(
                "{} has no attribute '{}'".format(type(self), unused_arg),
                DraftsmanWarning,
                stacklevel=2,
            )

    # =========================================================================

    @ControlBehaviorMixin.control_behavior.setter
    def control_behavior(self, value):
        # type: (dict) -> None
        try:
            self._control_behavior = signatures.ACCUMULATOR_CONTROL_BEHAVIOR.validate(
                value
            )
        except SchemaError as e:
            six.raise_from(DataFormatError(e), None)

    # =========================================================================

    @property
    def output_signal(self):
        # type: () -> dict
        """
        The signal used to output this accumulator's charge level, if set.

        :getter: Gets the output signal, or ``None`` if not set.
        :setter: Sets the output signal. Removes the key if set to ``None``.
        :type: :py:data:`.SIGNAL_ID`

        :exception InvalidSignalError: If set to a string not recognized as a valid
            signal name.
        :exception DataFormatError: If set to a ``dict`` that does not comply
            with the :py:data:`.SIGNAL_ID` format.
        """
        return self.control_behavior.get("output_signal", None)

    @output_signal.setter
    def output_signal(self, value):
        # type: (str) -> None
        if value is None:
            self.control_behavior.pop("output_signal", None)
        elif isinstance(value, six.string_types):
            value = six.text_type(value)
            self.control_behavior["output_signal"] = signal_dict(value)
        else:  # dict or other
            try:
                value = signatures.SIGNAL_ID.validate(value)
                self.control_behavior["output_signal"] = value
            except SchemaError as e:
                six.raise_from(DataFormatError(e), None)

==> factorio-draftsman-1.0.3.tar.gz: factorio-draftsman-1.0.3/draftsman/prototypes/accumulator.py <==
# accumulator.py
# -*- encoding: utf-8 -*-

from __future__ import unicode_literals

from draftsman import signatures
from draftsman.classes.entity import Entity
from draftsman.classes.mixins import ControlBehaviorMixin, CircuitConnectableMixin
from draftsman.error import DataFormatError
from draftsman.warning import DraftsmanWarning

from draftsman.data.entities import accumulators
from draftsman.data.signals import signal_dict

from schema import SchemaError
import six
import warnings


class Accumulator(ControlBehaviorMixin, CircuitConnectableMixin, Entity):
    """
    An entity that stores electricity for periods of high demand.
    """

    # fmt: off
    # _exports = {
    #     **Entity._exports,
    #     **CircuitConnectableMixin._exports,
    #     **ControlBehaviorMixin._exports,
    # }
    # fmt: on

    _exports = {}
    _exports.update(Entity._exports)
    _exports.update(CircuitConnectableMixin._exports)
    _exports.update(ControlBehaviorMixin._exports)

    def __init__(self, name=accumulators[0], **kwargs):
        # type: (str, **dict) -> None
        """
        TODO
        """

        super(Accumulator, self).__init__(name, accumulators, **kwargs)

        for unused_arg in self.unused_args:
            warnings.warn(
                "{} has no attribute '{}'".format(type(self), unused_arg),
                DraftsmanWarning,
                stacklevel=2,
            )

    # =========================================================================

    @ControlBehaviorMixin.control_behavior.setter
    def control_behavior(self, value):
        # type: (dict) -> None
        try:
            self._control_behavior = signatures.ACCUMULATOR_CONTROL_BEHAVIOR.validate(
                value
            )
        except SchemaError as e:
            six.raise_from(DataFormatError(e), None)

    # =========================================================================

    @property
    def output_signal(self):
        # type: () -> dict
        """
        The signal used to output this accumulator's charge level, if set.

        :getter: Gets the output signal, or ``None`` if not set.
        :setter: Sets the output signal. Removes the key if set to ``None``.
        :type: :py:data:`.SIGNAL_ID`

        :exception InvalidSignalError: If set to a string not recognized as a valid
            signal name.
        :exception DataFormatError: If set to a ``dict`` that does not comply
            with the :py:data:`.SIGNAL_ID` format.
        """
        return self.control_behavior.get("output_signal", None)

    @output_signal.setter
    def output_signal(self, value):
        # type: (str) -> None
        if value is None:
            self.control_behavior.pop("output_signal", None)
        elif isinstance(value, six.string_types):
            value = six.text_type(value)
            self.control_behavior["output_signal"] = signal_dict(value)
        else:  # dict or other
            try:
                value = signatures.SIGNAL_ID.validate(value)
                self.control_behavior["output_signal"] = value
            except SchemaError as e:
                six.raise_from(DataFormatError(e), None)
